@@ -2,5 +2,7 @@ pub mod hash_dir_path;
 pub mod hash;
 pub mod created_time_file;
 pub mod get_hash_times;
-pub mod is_reserved_filename;
+pub mod reserved_filename;
+pub mod prepare_hash_dir;
+pub mod remove_hash_dir;
 
