@@ -1,8 +1,9 @@
-pub mod cacher;
+pub mod cache;
 pub mod diff_src;
 pub mod accumulate_diff;
 pub mod diff_value;
 pub mod dochy_src;
 pub mod dochy_diff;
-pub mod dochy_cache;
+pub mod impl_cache_for_dochy_cache;
 pub mod open_diff_file_without_metadata;
+pub mod dochy_cache;
