@@ -3,7 +3,7 @@ use crate::error::FsResult;
 use std::fs::{read_dir};
 use std::time::SystemTime;
 
-pub fn show_dir_contents_history<P : AsRef<Path>>(path : P) -> FsResult<Vec<(String, usize)>>{
+pub(crate) fn show_dir_contents_history<P : AsRef<Path>>(path : P) -> FsResult<Vec<(String, usize)>>{
     let mut r : Vec<(SystemTime, String,usize)> = vec![];
     let dir = read_dir(path)?;
 
@@ -19,3 +19,11 @@ pub fn show_dir_contents_history<P : AsRef<Path>>(path : P) -> FsResult<Vec<(Str
     let r : Vec<(String, usize)> = r.into_iter().map(|(_,s,u)| (s,u)).collect();
     Ok(r)
 }
+
+pub fn show_history_dir<P : AsRef<Path>>(path : P) -> FsResult<()>{
+    let hoge = show_dir_contents_history(path)?;
+    for (name,size) in &hoge{
+        println!("{} {}", name, size);
+    }
+    Ok(())
+}
\ No newline at end of file
